/**
 * 
 */
package jalview.gui;

import java.util.BitSet;
import java.util.Vector;

import jalview.bin.Cache;
import jalview.datamodel.PDBEntry;
import jalview.datamodel.SequenceI;

import org.jmol.popup.JmolPopup;

class AppJmolBinding extends jalview.ext.jmol.JalviewJmolBinding
{

  /**
   * 
   */
  private AppJmol appJmolWindow;

  public AppJmolBinding(AppJmol appJmol, PDBEntry[] pdbentry,
          SequenceI[] seq, String[] chains, String protocol)
  {
    super(pdbentry, seq, chains, protocol);
    appJmolWindow = appJmol;
  }
  FeatureRenderer fr=null;
  @Override
  public jalview.api.FeatureRenderer getFeatureRenderer()
  {
    if (appJmolWindow.ap.av.showSequenceFeatures)
    {
      if (fr == null)
      {
        fr = new FeatureRenderer(appJmolWindow.ap);
      }

      fr.transferSettings(appJmolWindow.ap.seqPanel.seqCanvas
                      .getFeatureRenderer());
    }

    return fr;
  }

  @Override
  public jalview.api.SequenceRenderer getSequenceRenderer()
  {
    return new SequenceRenderer(appJmolWindow.ap.av);
  }

  public void sendConsoleEcho(String strEcho)
  {
    if (appJmolWindow.scriptWindow != null)
    {
      appJmolWindow.scriptWindow.sendConsoleEcho(strEcho);
    }
  }

  public void sendConsoleMessage(String strStatus)
  {
    if (appJmolWindow.scriptWindow!=null && strStatus != null
            )
      //      && !strStatus.equals("Script completed"))
      // should we squash the script completed string ?
    {
      appJmolWindow.scriptWindow.sendConsoleMessage(strStatus);
    }
  }

  @Override
  public void showUrl(String url, String target)
  {
    try {
      jalview.util.BrowserLauncher.openURL(url);
    } catch (Exception e) {
      Cache.log.error("Failed to launch Jmol-associated url " + url, e);
      // TODO: 2.6 : warn user if browser was not configured.
    }
  }

  @Override
  public void refreshGUI()
  {
    // appJmolWindow.repaint();
    appJmolWindow.updateTitleAndMenus();
  }

  public void updateColours(Object source)
  {
    AlignmentPanel ap = (AlignmentPanel) source;
    if (appJmolWindow.ap.alignFrame.getCurrentView()!=ap.av)
      return;
    
    colourBySequence(ap.av.getShowSequenceFeatures(), ap.av.alignment);
  }

  public void notifyScriptTermination(String strStatus, int msWalltime)
  {
    if (appJmolWindow.scriptWindow != null)
      appJmolWindow.scriptWindow.notifyScriptTermination(strStatus, msWalltime);
  }

  public void showUrl(String url)
  {
    showUrl(url,"jmol");
  }

  public void newJmolPopup(boolean translateLocale, String menuName,
          boolean asPopup)
  {

    jmolpopup = JmolPopup.newJmolPopup(viewer, translateLocale, menuName,
            asPopup);
  }
  public synchronized void addSequence(SequenceI[] seq)
  {
    Vector v = new Vector();
    for (int i = 0; i < sequence.length; i++)
      v.addElement(sequence[i]);

    for (int i = 0; i < seq.length; i++)
      if (!v.contains(seq[i]))
        v.addElement(seq[i]);

    SequenceI[] tmp = new SequenceI[v.size()];
    v.copyInto(tmp);
    sequence = tmp;
  }

  public void selectionChanged(BitSet arg0)
  {
    // TODO Auto-generated method stub
    
  }

  public void refreshPdbEntries()
  {
    // TODO Auto-generated method stub
    
  }
}